Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1180)

Unified Diff: base/memory/shared_memory_helper.h

Issue 2872503003: Add crash keys about field trial shared memory errors. (Closed)
Patch Set: Rebased Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/memory/shared_memory.h ('k') | base/memory/shared_memory_helper.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/memory/shared_memory_helper.h
diff --git a/base/memory/shared_memory_helper.h b/base/memory/shared_memory_helper.h
index b515828c08c4952bdfba476b65ebca878f1fe487..5c8b86e618de1149d089beb225db9c7adcc634d1 100644
--- a/base/memory/shared_memory_helper.h
+++ b/base/memory/shared_memory_helper.h
@@ -16,16 +16,21 @@ namespace base {
// with the fdopened FILE. |readonly_fd| is populated with the opened fd if
// options.share_read_only is true. |path| is populated with the location of
// the file before it was unlinked.
// Returns false if there's an unhandled failure.
bool CreateAnonymousSharedMemory(const SharedMemoryCreateOptions& options,
ScopedFILE* fp,
ScopedFD* readonly_fd,
- FilePath* path);
+ FilePath* path,
+ SharedMemoryError* error);
// Takes the outputs of CreateAnonymousSharedMemory and maps them properly to
// |mapped_file| or |readonly_mapped_file|, depending on which one is populated.
-bool PrepareMapFile(ScopedFILE fp, ScopedFD readonly_fd, int* mapped_file,
- int* readonly_mapped_file);
+// Returns false if there's a failure and sets |error|.
+bool PrepareMapFile(ScopedFILE fp,
+ ScopedFD readonly_fd,
+ int* mapped_file,
+ int* readonly_mapped_file,
+ SharedMemoryError* error);
#endif
} // namespace base
« no previous file with comments | « base/memory/shared_memory.h ('k') | base/memory/shared_memory_helper.cc » ('j') | no next file with comments »
@@ -16,16 +16,21 @@ namespace base {
// options.share_read_only is true. |path| is populated with the location of
// the file before it was unlinked.
-// Returns false if there's an unhandled failure.
+// Returns false if there's a failure and sets |error|.
bool CreateAnonymousSharedMemory(const SharedMemoryCreateOptions& options,
ScopedFILE* fp,

Powered by Google App Engine
This is Rietveld 408576698